@@ -20,11 +20,11 @@
  *	with this program; if not, write to the Free Software Foundation, Inc.,
  *	675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: hotplug.c,v 1.4 2001/08/30 00:13:33 kroah Exp $
+ * $Id: hotplug.c,v 1.6 2002/01/04 19:02:20 kroah Exp $
  * 
  */
 
-#include <stdlib.h>
+#include "stddef.h"
 #include "hotplug.h"
 #include "hotplug_version.h"
 
@@ -47,6 +47,7 @@ int dock_handler (void)
 static struct subsystem main_subsystem[] = {
 	{ "pci", pci_handler },
 	{ "usb", usb_handler },
+	{ "ieee1394", ieee1394_handler },
 	{ "cpu", cpu_handler },
 	{ "net", net_handler },
 	{ "dock", dock_handler },
