@@ -18,11 +18,13 @@
  *	with this program; if not, write to the Free Software Foundation, Inc.,
  *	675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: usb.c,v 1.7 2001/10/11 00:17:42 kroah Exp $
+ * $Id: usb.c,v 1.10 2002/01/04 19:01:52 kroah Exp $
  * 
  */
 
-#include <stdlib.h>
+#include "stddef.h"	/* for NULL */
+#include "stdlib.h"	/* for getenv() */
+#include "errno.h"
 #include "hotplug.h"
 
 #include "usb_modules.h"
@@ -46,9 +48,10 @@
 	
 
 
-static struct usb_module_map * match_vendor_product (unsigned short vendor, unsigned short product, unsigned short bcdDevice)
+static int match_vendor_product (unsigned short vendor, unsigned short product, unsigned short bcdDevice)
 {
 	int i;
+	int retval;
 
 	dbg ("vendor = %x, product = %x, bcdDevice = %x", vendor, product, bcdDevice);
 
@@ -76,18 +79,21 @@ static struct usb_module_map * match_vendor_product (unsigned short vendor, unsi
 				continue;
 			}
 			/* found one! */
-			dbg ("returning %s", usb_module_map[i].module_name);
-			return &usb_module_map[i];
+			dbg ("loading %s", usb_module_map[i].module_name);
+			retval = load_module (usb_module_map[i].module_name);
+			if (retval)
+				return retval;
 		}
 	}
 
-	return NULL;
+	return -ENODEV;
 }
 	
 
-static struct usb_module_map * match_device_class (unsigned char class, unsigned char subclass, unsigned char protocol)
+static int match_device_class (unsigned char class, unsigned char subclass, unsigned char protocol)
 {
 	int i;
+	int retval;
 
 	dbg ("class = %x, subclass = %x, protocol = %x", class, subclass, protocol);
 
@@ -110,18 +116,21 @@ static struct usb_module_map * match_device_class (unsigned char class, unsigned
 				continue;
 			}
 			/* found one! */
-			dbg ("returning %s", usb_module_map[i].module_name);
-			return &usb_module_map[i];
+			dbg ("loading %s", usb_module_map[i].module_name);
+			retval = load_module (usb_module_map[i].module_name);
+			if (retval)
+				return retval;
 		}
 	}
 
-	return NULL;
+	return -ENODEV;
 }
 
 
-static struct usb_module_map * match_interface_class (unsigned char class, unsigned char subclass, unsigned char protocol)
+static int match_interface_class (unsigned char class, unsigned char subclass, unsigned char protocol)
 {
 	int i;
+	int retval;
 
 	dbg ("class = %x, subclass = %x, protocol = %x", class, subclass, protocol);
 
@@ -144,18 +153,19 @@ static struct usb_module_map * match_interface_class (unsigned char class, unsig
 				continue;
 			}
 			/* found one! */
-			dbg ("returning %s", usb_module_map[i].module_name);
-			return &usb_module_map[i];
+			dbg ("loading %s", usb_module_map[i].module_name);
+			retval = load_module (usb_module_map[i].module_name);
+			if (retval)
+				return retval;
 		}
 	}
 
-	return NULL;
+	return -ENODEV;
 }
 
 
 static int usb_add (void)
 {
-	struct usb_module_map *usb_module;
 	char *product_env;
 	char *type_env;
 	char *interface_env;
@@ -181,21 +191,21 @@ static int usb_add (void)
 	if (error)
 		return error;
 
-	usb_module = match_vendor_product (idVendor, idProduct, bcdDevice);
-	if (usb_module != NULL)
-		return load_module (usb_module->module_name);
+	error = match_vendor_product (idVendor, idProduct, bcdDevice);
+	if (error)
+		return error;
 	
 	error = split_3values (type_env, 10, &device_class,
 			       &device_subclass, &device_protocol);
 	if (error)
 		return error;
-	usb_module = match_device_class ((unsigned char)device_class, 
-					 (unsigned char)device_subclass,
-					 (unsigned char)device_protocol);
-	if (usb_module != NULL)
-		return load_module (usb_module->module_name);
+	error = match_device_class ((unsigned char)device_class,
+				    (unsigned char)device_subclass,
+				    (unsigned char)device_protocol);
+	if (error)
+		return error;
 
-	/* we need to look at the interface then */
+	/* we need to look at the interface too */
 	interface_env = getenv ("INTERFACE");
 	if (interface_env == NULL) {
 		dbg ("interface is null, we don't know what to do here.");
@@ -205,14 +215,10 @@ static int usb_add (void)
 			       &interface_subclass, &interface_protocol);
 	if (error)
 		return error;
-	usb_module = match_interface_class ((unsigned char)interface_class,
-					    (unsigned char)interface_subclass,
-					    (unsigned char)interface_protocol);
-	if (usb_module != NULL)
-		return load_module (usb_module->module_name);
-	
-	dbg ("no match found.");
-	return 1;
+	error = match_interface_class ((unsigned char)interface_class,
+				       (unsigned char)interface_subclass,
+				       (unsigned char)interface_protocol);
+	return error;
 }
 
 
