@@ -18,13 +18,14 @@
  *	with this program; if not, write to the Free Software Foundation, Inc.,
  *	675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: util.c,v 1.6 2001/10/12 21:28:45 kroah Exp $
+ * $Id: util.c,v 1.9 2001/12/15 18:39:29 kroah Exp $
  * 
  */
 
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
+#include "stddef.h"	/* for NULL */
+#include "string.h"
+#include "stdlib.h"	/* for exit() */
+#include "unistd.h"
 #include "hotplug.h"
 
 /**
@@ -34,7 +35,7 @@
  * values for xxxx and yyyy
  * 
  */
-int split_2values (const char *string, int base, unsigned int * value1, unsigned int * value2)
+int split_2values (const char *string, int base, unsigned int *value1, unsigned int *value2)
 {
 	char buffer[200];
 	char *temp1;
@@ -62,7 +63,7 @@ int split_2values (const char *string, int base, unsigned int * value1, unsigned
 		++temp2;
 	}
 	*temp1 = 0x00;
-	*value1 = strtol (buffer, NULL, base);
+	*value1 = strtoul (buffer, NULL, base);
 	dbg ("buffer = %s", &buffer[0]);
 	dbg ("value1 = %d", *value1);
 
@@ -82,7 +83,7 @@ int split_2values (const char *string, int base, unsigned int * value1, unsigned
 		++temp2;
 	}
 	*temp1 = 0x00;
-	*value2 = strtol (buffer, NULL, base);
+	*value2 = strtoul (buffer, NULL, base);
 	dbg ("buffer = %s", &buffer[0]);
 	dbg ("value2 = %d", *value2);
 
@@ -125,7 +126,7 @@ int split_3values (const char *string, int base, unsigned int * value1, unsigned
 		++temp2;
 	}
 	*temp1 = 0x00;
-	*value1 = strtol (buffer, NULL, base);
+	*value1 = strtoul (buffer, NULL, base);
 	dbg ("buffer = %s", &buffer[0]);
 	dbg ("value1 = %d", *value1);
 
@@ -147,7 +148,7 @@ int split_3values (const char *string, int base, unsigned int * value1, unsigned
 		++temp2;
 	}
 	*temp1 = 0x00;
-	*value2 = strtol (buffer, NULL, base);
+	*value2 = strtoul (buffer, NULL, base);
 	dbg ("buffer = %s", &buffer[0]);
 	dbg ("value2 = %d", *value2);
 
@@ -167,7 +168,7 @@ int split_3values (const char *string, int base, unsigned int * value1, unsigned
 		++temp2;
 	}
 	*temp1 = 0x00;
-	*value3 = strtol (buffer, NULL, base);
+	*value3 = strtoul (buffer, NULL, base);
 	dbg ("buffer = %s", &buffer[0]);
 	dbg ("value3 = %d", *value3);
 
@@ -189,8 +190,24 @@ int subsystem (const char *string, struct subsystem *subsystem)
 
 int load_module (const char *module_name)
 {
+	char *argv[3];
+
+	argv[0] = "/sbin/modprobe";
+	argv[1] = (char *)module_name;
+	argv[2] = NULL;
 	dbg ("loading module %s", module_name);
-	execlp ("modprobe", "modprobe", module_name, 0);
+	switch (fork()) {
+		case 0:
+			/* we are the child, so lets run the program */
+			execv ("/sbin/modprobe", argv);
+			exit(0);
+			break;
+		case (-1):
+			dbg ("fork failed.");
+			break;
+		default:
+			break;
+	}
 	return 0;
 }
 
